@@ -12,11 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-__version__ = "3.1.0"
+__version__ = "3.2.0"
 AUTHOR = "Guillermo Adrián Molina"
 AUTHOR_EMAIL = "guillermoadrianmolina@hotmail.com"
 NAME = "zfs-clone-manager"
 PACKAGE_URL = "http://www.github.com/guillermomolina/zfs-clone-manager"
 KEYWORDS = "zfs"
-DESCRIPTION = "Tools to manage ZFS clones with history metadata"
+DESCRIPTION = "Tool to manage ZFS clones with history metadata"
 LICENSE = "LICENSE"
